==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebColumnMovingStartEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnMovingStartEventArgsDetailDescriptionMetadata } from "./WebColumnMovingStartEventArgsDetailDescriptionMetadata";
import { WebColumnMovingStartEventArgsDescription } from "./WebColumnMovingStartEventArgsDescription";
/**
 * @hidden
 */
export let WebColumnMovingStartEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnMovingStartEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnMovingStartEventArgsDescriptionMetadata.a == null) {
                WebColumnMovingStartEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnMovingStartEventArgsDescriptionMetadata.c(WebColumnMovingStartEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebColumnMovingStartEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebColumnMovingStartEventArgsDescriptionMetadata.a);
            WebColumnMovingStartEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ColumnMovingStartEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebColumnMovingStartEventArgsDetail");
        }
        static d(a) {
            WebColumnMovingStartEventArgsDescriptionMetadata.b(a);
            a.ad("WebColumnMovingStartEventArgs", () => new WebColumnMovingStartEventArgsDescription());
            a.ac("WebColumnMovingStartEventArgs", WebColumnMovingStartEventArgsDescriptionMetadata.a);
        }
    }
    WebColumnMovingStartEventArgsDescriptionMetadata.$t = markType(WebColumnMovingStartEventArgsDescriptionMetadata, 'WebColumnMovingStartEventArgsDescriptionMetadata');
    WebColumnMovingStartEventArgsDescriptionMetadata.a = null;
    return WebColumnMovingStartEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebColumnMovingStartEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnMovingStartEventArgsDetailDescriptionMetadata } from "./WebColumnMovingStartEventArgsDetailDescriptionMetadata";
import { WebColumnMovingStartEventArgsDescription } from "./WebColumnMovingStartEventArgsDescription";
/**
 * @hidden
 */
export let WebColumnMovingStartEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnMovingStartEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnMovingStartEventArgsDescriptionMetadata.a == null) {
                WebColumnMovingStartEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnMovingStartEventArgsDescriptionMetadata.c(WebColumnMovingStartEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebColumnMovingStartEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebColumnMovingStartEventArgsDescriptionMetadata.a);
            WebColumnMovingStartEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ColumnMovingStartEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebColumnMovingStartEventArgsDetail");
        }
        static d(a) {
            WebColumnMovingStartEventArgsDescriptionMetadata.b(a);
            a.ae("WebColumnMovingStartEventArgs", () => new WebColumnMovingStartEventArgsDescription());
            a.ad("WebColumnMovingStartEventArgs", WebColumnMovingStartEventArgsDescriptionMetadata.a);
        }
    }
    WebColumnMovingStartEventArgsDescriptionMetadata.$t = markType(WebColumnMovingStartEventArgsDescriptionMetadata, 'WebColumnMovingStartEventArgsDescriptionMetadata');
    WebColumnMovingStartEventArgsDescriptionMetadata.a = null;
    return WebColumnMovingStartEventArgsDescriptionMetadata;
})();
